c3errors.ConfigFileException

|  | ## Cheshire3 Object Model: Class ConfigFileException

Module c3errors :: Class ConfigFileException

## Class ConfigFileException
source code

Object Tree:

    exceptions.Exception --+
                           |
                 C3Exception --+
                               |
                              ConfigFileException

Instance Methods

Inherited from `C3Exception`: `__init__`, `__str__` Inherited from `exceptions.Exception`: `__getitem__`

Class Variables

Inherited from `C3Exception`: `text`